@@ -7,6 +7,7 @@ from email.mime.multipart import MIMEMultipart
 from email.utils import formataddr
 from email.mime.text import MIMEText
 import smtplib
+import requests
 from email.mime.application import MIMEApplication
 import logging
 from email.mime.text import MIMEText
@@ -476,3 +477,28 @@ class EmailSend(object):
 
     def send_video_email(self):
         pass
+
+
+url = "http://elanpy.com:39111/?key=123&method=scrapy"
+
+def getIP():
+    res = requests.get(url).json()
+    return res
+
+def addWhite(res):
+    ip_url = "http://httpbin.org/ip"
+    ip_res = requests.get(ip_url).json()["origin"]
+    whiteList = requests.post(url, data={"secret":res["proxyPass"], "ip":ip_res, "order_id":res["proxyUser"]}).json()
+    if str(whiteList["code"])=="200":
+        return True
+    else:
+        ezfuc.sleep(2)
+        ezfuc.color_print("添加白名单失败")
+        addWhite(res)
+
+def ezproxy(req, add_white=True):
+    res = getIP()
+    if add_white:
+        addWhite(res)
+    req.meta["proxy"] = res["proxy"]
+    return req
\ No newline at end of file
